@@ -2,19 +2,15 @@
 
 package Dancer2::Core::Response;
 {
-    $Dancer2::Core::Response::VERSION = '0.09';
+    $Dancer2::Core::Response::VERSION = '0.10';
 }
 
-use strict;
-use warnings;
-use Carp;
 use Moo;
+
 use Encode;
 use Dancer2::Core::Types;
 
-use Scalar::Util qw/looks_like_number blessed/;
 use Dancer2 ();
-use Dancer2::Core::MIME;
 use Dancer2::Core::HTTP;
 
 use overload
@@ -36,15 +32,15 @@ has has_passed => (
 );
 
 
+sub pass { shift->has_passed(1) }
+
+
 has serializer => (
-    is        => 'rw',
+    is        => 'ro',
     isa       => Maybe( ConsumerOf ['Dancer2::Core::Role::Serializer'] ),
-    required  => 0,
     predicate => 1,
 );
 
-sub pass { shift->has_passed(1) }
-
 
 has is_encoded => (
     is      => 'rw',
@@ -68,11 +64,7 @@ has status => (
     isa     => Num,
     default => sub {200},
     lazy    => 1,
-    coerce  => sub {
-        my ($status) = @_;
-        return $status if looks_like_number($status);
-        Dancer2::Core::HTTP->status($status);
-    },
+    coerce  => sub { Dancer2::Core::HTTP->status(shift) },
 
     # This trigger makes sure we drop the content whenever
     # we set the status to [23]04.
@@ -89,19 +81,17 @@ has content => (
     isa     => Str,
     default => sub {''},
     coerce  => sub {
-        my ($value) = @_;
-        $value = "$value" if ref($value);
-        return $value;
+        my $value = shift;
+        return "$value";
     },
 
    # This trigger makes sure we have a good content-length whenever the content
    # changes
     trigger => sub {
         my ( $self, $value ) = @_;
-        $self->header( 'Content-Length' => length($value) )
-          if !$self->has_passed;
-
-        $value;
+        $self->has_passed
+          or $self->header( 'Content-Length' => length($value) );
+        return $value;
     },
 );
 
@@ -119,7 +109,7 @@ sub encode_content {
     return if $self->content_type !~ /^text/;
 
     # we don't want to encode an empty string, it will break the output
-    return if !$self->content;
+    $self->content or return;
 
     my $ct = $self->content_type;
     $self->content_type("$ct; charset=UTF-8")
@@ -186,17 +176,16 @@ sub error {
     );
 
     $error->throw;
-
     return $error;
 }
 
+
 sub serialize {
     my ( $self, $content ) = @_;
-
     return unless $self->has_serializer;
 
-    $content = $self->serializer->serialize($content);
-    return if !defined $content;
+    $content = $self->serializer->serialize($content)
+      or return;
 
     $self->content_type( $self->serializer->content_type );
     return $content;
@@ -214,7 +203,7 @@ Dancer2::Core::Response - Response object for Dancer2
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 ATTRIBUTES
 
@@ -240,10 +229,13 @@ unless the response has_passed.
 
 =head1 METHODS
 
-=head2 serializer( $serializer )
+=head2 pass
 
-Set or returns the optional serializer object used to deserialize request
-parameters
+Set has_passed to true.
+
+=head2 serializer()
+
+Returns the optional serializer object used to deserialize request parameters
 
 =head2 halt
 
@@ -280,6 +272,13 @@ status to $status.  If $status is omitted, or false, then it defaults to a statu
 Creates a L<Dancer2::Core::Error> object with the given I<@args> and I<throw()>
 it against the response object. Returns the error object.
 
+=head2 serialize( $content )
+
+    $response->serialize( $content );
+
+Serialize and return $content with the respone's serializer.
+set content-type accordingly.
+
 =head1 AUTHOR
 
 Dancer Core Developers
