@@ -2,7 +2,7 @@
 
 package Dancer2::Core::Role::DSL;
 {
-    $Dancer2::Core::Role::DSL::VERSION = '0.09';
+    $Dancer2::Core::Role::DSL::VERSION = '0.10';
 }
 use Moo::Role;
 use Dancer2::Core::Types;
@@ -69,14 +69,7 @@ sub export_symbols_to {
 sub _compile_keyword {
     my ( $self, $keyword, $is_global ) = @_;
 
-    my $compiled_code = sub {
-        Dancer2::Core::debug( "["
-              . $self->app->name
-              . "] -> $keyword("
-              . join( ', ', map { defined() ? $_ : '<undef>' } @_ )
-              . ")" );
-        $self->$keyword(@_);
-    };
+    my $compiled_code = sub { $self->$keyword(@_); };
 
     if ( !$is_global ) {
         my $code = $compiled_code;
@@ -117,7 +110,7 @@ Dancer2::Core::Role::DSL - Role for DSL
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 AUTHOR
 
