@@ -12,12 +12,12 @@ around dsl_keywords => sub {
     my $orig     = shift;
     my $keywords = $orig->(@_);
 
-    push @$keywords, [ gateau => 0 ],    # cookie
-      [ moteur => 1 ],                   # engine
-      [ stop   => 0 ],                   # halt
-      [ prend  => 1 ],                   # post
-      [ envoie => 1 ],                   # post
-      [ entete => 0 ];                   #header
+    $keywords->{gateau} = { is_global => 0 };    # cookie
+    $keywords->{moteur} = { is_global => 1 };    # engine
+    $keywords->{stop}   = { is_global => 0 };    # halt
+    $keywords->{prend}  = { is_global => 1 };    # post
+    $keywords->{envoie} = { is_global => 1 };    # post
+    $keywords->{entete} = { is_global => 0 };    #header
 
     return $keywords;
 };
